% Matlab script fig4_sedimentation_and_erosion_1D_geotherm_transient.m
% Todd Ehlers, September 2004.
%
% Designed to find an analytic solution for effects of sedimentation and
% erosion on geotherms.
% 
% Equation taken from Haenel, "Handbook of Terrestrial Heat Flow
% Density Determination" page 209.
% 
%
% Definition of Variables:
%
%  z=depth
%  t=time
%  To=surface temp.
%  Tl=lapse rate= adiabatic gradient in air (~7 degrees/km).
%  v= +v implies sedimentation, -v implies erosion.
%  Tb= basal temp. gradient, often unknown {see page 176},(~ 30 dgr C/km)
%  u= rate of movement w.r.t. to a fixed reference
%  a= thermal diffusivity
%

% ***
% *** USER DEFINED VARIABLES BELOW
% ***

clear all
close all
To=0;         % degrees celcius
Tb=25;        % celcius/km
v=1.0;          % Sedimentation rate (km/ma or mm/yr).  Input a positive value, will be changed automatically for erosion.              
%               v=0 ==> initial condition without heat production
Tl=7;         % celcius/km
u=0;          % km/ma  setting u=0 means the surface of depo/erosion 
              % remains as a fixed point in space, ie z=0= surface.
a=32;         % km^2/my
t=[0:5:15];   % Time range (Ma) over which geotherms will be calculated
z=[0:0.5:15]; % Depth range (km) over which geotherms will be calculated

% ***
% *** SEDIMENTATION *****************************************************
% ***

for j=1:length(t)
for i=1:length(z)
    IT(i,j)=To+(Tb*(z(i)-v*t(j)))+(1/2)*(Tb+(Tl*u)/v)*((z(i)+v*t(j))*exp((v*z(i))/a)*erfc((z(i)+v*t(j))/(2*(a*t(j))^.5))-(z(i)-v*t(j))*erfc((z(i)-v*t(j))/(2*(a*t(j))^.5)));
end
 end
% ***
% *** PLOT RESULTS ***
% ***
figure
subplot(121)
plot(IT,-1*z,'k-')
axis([0,250,-10,0])
ylabel('Depth (km)')
xlabel('Temperature (C)')
title('Sedimentation: 1 mm/yr')

% ***
% *** EROSION *****************************************************
% ***

v=-1*v; % Change sign on velocity for erosion

for j=1:length(t)
for i=1:length(z)
    IT(i,j)=To+(Tb*(z(i)-v*t(j)))+(1/2)*(Tb+(Tl*u)/v)*((z(i)+v*t(j))*exp((v*z(i))/a)*erfc((z(i)+v*t(j))/(2*(a*t(j))^.5))-(z(i)-v*t(j))*erfc((z(i)-v*t(j))/(2*(a*t(j))^.5)));
end
 end
% ***
% *** PLOT RESULTS ***
% ***
subplot(122)
plot(IT,-1*z,'k-')
axis([0,450,-10,0])
ylabel('Depth (km)')
xlabel('Temperature (C)')
title('Erosion: 1 mm/yr')

% ***
% *** END OF GEOTHERM CALCULATION
% ***



