% Matlab script fig5_sedimentation_and_erosion_1D_gradient_transient.m
%   Todd Ehlers September, 2004
%
%  
%  This Script will calculate the thermal gradient effect as a function of
%   erosion and sedimentation for a 1-D half-space at a user defined depth.
%  Equation used below is from Haenel, "Handbook of Terrestrial Heat Flow
%  Density Determination" page 210.
%
%  z=depth
%  tt=time  (in millions of years)
%  To=surface temp.
%  Tl=lapse rate= adiabatic gradient in air (~7 degrees/km).
%  v= +v implies sedimentation, -v implies erosion.
%  Tb= basal temp. gradient, often unknown {see page 176},(~ 30 dgr C/km)
%  u= rate of movement w.r.t. to a fixed reference
%  a= thermal diffusivity
%

% Clear variables out of memory and close all open plots

clear all 
close all

% ***
% *** USER DEFINED VARIABLES BELOW
% ***
    To=0;         % surface temperature degrees [celcius]
    Tb=50;        % basal thermal gradient [celcius/km]
    tstart=[0.0001:0.001:100]; % Time that solutions will be calculated at [myr]
  %  tstart=[0.0001:0.01:100]; % Time that solutions will be calculated at [myr]
   vstart=[0.01 0.1 1.0 10.0]; % Veloctiy of erosion or sedimentation considered [mm/yr]
    Tl=7;         % atmospheric adiabatic lapse rate [celcius/km]
    u=0;          % velocity of surface uplift [km/ma]  setting u=0 means the surface of depo/erosion 
              % remains as a fixed point in space, ie z=0= surface.
    a=32;         % Thermal diffusivity [km^2/my]
    z=0;          % Depth at which solution will be calculated.  Postive downward coordinate system [km]

% *** END OF VARIABLES USERS CAN CHANGE    
    
% ***
% *** SEDIMENTATION - THERMAL GRADIENT EFFECT AT EARTH'S SURFACE
% ***

% Initialize velocity term for erosion, initialize time array
    t=tstart;
    v=vstart;

% Calculate solution
    t=tstart;
    v=vstart;
    for j=1:length(t)   % loop over time history
    for i=1:length(v)   % loop over velocities
         Grad(i,j)=Tb+1/2*(Tb+(Tl*u)/v(i))*(-erfc((z-v(i)*t(j))/(2*(a*t(j))^.5))-((z+v(i)*t(j))/(pi*a*t(j))^.5)*exp((v(i)*z)/a)*exp(-((z+v(i)*t(j))/(2*(a*t(j))^.5))^2)+((z-v(i)*t(j))/(pi*a*t(j))^.5)*exp(-((z-v(i)*t(j))/(2*(a*t(j))^.5))^2)+(1+(v(i)*z)/a+(v(i)^2*t(j))/a)*exp((v(i)*z)/a)*erfc((z+v(i)*t(j))/(2*(a*t(j))^.5)));
         pg(i,j)=((Tb-Grad(i,j))/Tb)*100;
    end
    end

% Calculated the log10 of time for plotting purposes
    t=t*1e6; % convert time from Myr to years
    lt=log10(t);

% Plot % gradient results
    figure
    Orient tall
    subplot(323)
    plot(lt,pg,'k-')
    axis([2,9,0,101])
    xlabel('Log10 Time')
    ylabel('Thermal Gradient Decrease (%)')
    title('Sedimentation Effect: Earths Surface')

    
% ***
% *** EROSION - THERMAL GRADIENT EFFECT AT EARTH'S SURFACE
% ***

% Switch sign on velocity term for erosion, initialize time array
    t=tstart;
    v=-1*vstart;

% Calculate solution
    for j=1:length(t)   % loop over time history
    for i=1:length(v)   % loop over velocities
         GradE(i,j)=Tb+1/2*(Tb+(Tl*u)/v(i))*(-erfc((z-v(i)*t(j))/(2*(a*t(j))^.5))-((z+v(i)*t(j))/(pi*a*t(j))^.5)*exp((v(i)*z)/a)*exp(-((z+v(i)*t(j))/(2*(a*t(j))^.5))^2)+((z-v(i)*t(j))/(pi*a*t(j))^.5)*exp(-((z-v(i)*t(j))/(2*(a*t(j))^.5))^2)+(1+(v(i)*z)/a+(v(i)^2*t(j))/a)*exp((v(i)*z)/a)*erfc((z+v(i)*t(j))/(2*(a*t(j))^.5)));
         pgE(i,j)=(abs(Tb-GradE(i,j))/Tb)*100;
    end
    end

% Calculated the log10 of time for plotting purposes
    t=t*1e6; % convert time from Myr to years
    lt=log10(t);

% Plot % gradient results results
    subplot(324)
    plot(lt,pgE,'k-')
    axis([2,9,0,101])
    xlabel('Log10 Time')
    ylabel('Thermal Gradient Increase (%)')
    title('Erosion Effect: Earths Surface')
    
% Plot Temperature gradient results   
    subplot(321)
    plot(lt,Grad,'k')
    axis([2,9,0,26])
    xlabel('Log10 Time')
    ylabel('Thermal Gradient (C/km)')
    title('Sedimentation Effect: Earths Surface')
    
    subplot(322)
    plot(lt,GradE,'k')
    axis([2,9,20,125])
    xlabel('Log10 Time')
    ylabel('Thermal Gradient (C/km)')
    title('Erosion Effect: Earths Surface')
    
% ***
% *** CALCULATE SOLUTION AT 4km DEPTH FOR COMPARISON
% ***
    
    z=4;          % Depth at which solution will be calculated.  Postive downward coordinate system [km]

% ***
% *** SEDIMENTATION - THERMAL GRADIENT EFFECT AT 4km DEPTH
% ***

% Initialize velocity term for erosion, initialize time array
    t=tstart;
    v=vstart;

% Calculate solution
    t=tstart;
    v=vstart;
    for j=1:length(t)   % loop over time history
    for i=1:length(v)   % loop over velocities
         Grad(i,j)=Tb+1/2*(Tb+(Tl*u)/v(i))*(-erfc((z-v(i)*t(j))/(2*(a*t(j))^.5))-((z+v(i)*t(j))/(pi*a*t(j))^.5)*exp((v(i)*z)/a)*exp(-((z+v(i)*t(j))/(2*(a*t(j))^.5))^2)+((z-v(i)*t(j))/(pi*a*t(j))^.5)*exp(-((z-v(i)*t(j))/(2*(a*t(j))^.5))^2)+(1+(v(i)*z)/a+(v(i)^2*t(j))/a)*exp((v(i)*z)/a)*erfc((z+v(i)*t(j))/(2*(a*t(j))^.5)));
         pg(i,j)=((Tb-Grad(i,j))/Tb)*100;
    end
    end

% Calculated the log10 of time for plotting purposes
    t=t*1e6; % convert time from Myr to years
    lt=log10(t);

% Plot results
    subplot(325)
    plot(lt,pg,'k-')
    axis([2,9,0,101])
    xlabel('Log10 Time')
    ylabel('Thermal Gradient Decrease (%)')
    title('Sedimentation Effect: 4 km Depth')

% ***
% *** EROSION - THERMAL GRADIENT EFFECT AT 4km DEPTH
% ***

% Switch sign on velocity term for erosion, initialize time array
    t=tstart;
    v=-1*vstart;

% Calculate solution
    for j=1:length(t)   % loop over time history
    for i=1:length(v)   % loop over velocities
         GradE(i,j)=Tb+1/2*(Tb+(Tl*u)/v(i))*(-erfc((z-v(i)*t(j))/(2*(a*t(j))^.5))-((z+v(i)*t(j))/(pi*a*t(j))^.5)*exp((v(i)*z)/a)*exp(-((z+v(i)*t(j))/(2*(a*t(j))^.5))^2)+((z-v(i)*t(j))/(pi*a*t(j))^.5)*exp(-((z-v(i)*t(j))/(2*(a*t(j))^.5))^2)+(1+(v(i)*z)/a+(v(i)^2*t(j))/a)*exp((v(i)*z)/a)*erfc((z+v(i)*t(j))/(2*(a*t(j))^.5)));
         pgE(i,j)=(abs(Tb-GradE(i,j))/Tb)*100;
    end
    end

% Calculated the log10 of time for plotting purposes
    t=t*1e6;  % convert time from Myr to years
    lt=log10(t);

% Plot results
    subplot(326)
    plot(lt,pgE,'k-')
    axis([2,9,0,101])
    xlabel('Log10 Time')
    ylabel('Thermal Gradient Increase')
    title('Erosion Effect: 4 km Depth')    
   
 
    
% ***
% *** END OF FUNCTINO
% ***

